Test 04_Resolved_Issues was failing on VMS because it was translating ".." to "__". Use vmspath() instead so that dots are escaped if needed.

Also filed as:

http://rt.cpan.org/Public/Bug/Display.html?id=41329

-John
[EMAIL PROTECTED]
Personal Opinion Only
--- /rsync_root/perl/lib/Archive/Tar.pm Wed Oct 15 08:50:32 2008
+++ lib/Archive/Tar.pm  Sun Nov 30 17:33:31 2008
@@ -690,9 +690,9 @@
         }
 
         
-        ### '.' is the directory delimiter, of which the first one has to
-        ### be escaped/changed.
-        map tr/\./_/, @dirs if ON_VMS;        
+        ### '.' is the directory delimiter on VMS, of which the first one
+        ### has to be escaped/changed by vmspath
+        map $_ = VMS::Filespec::vmspath($_), @dirs if ON_VMS;        
 
         my ($cwd_vol,$cwd_dir,$cwd_file) 
                     = File::Spec->splitpath( $cwd );

Reply via email to